﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Input;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.DataPresenter.Events;
using Infragistics.Windows.Editors;
using EditModeStartedEventArgs = Infragistics.Windows.Editors.Events.EditModeStartedEventArgs;

namespace XamDataGridEnterBehavior
{
    /// <summary>
    /// Interaktionslogik für MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            ModifyReturnBehavior = true;
            InitializeComponent();
            DataGrid.FieldLayoutInitialized += DataGridFieldLayoutInitialized;
            this.DataContext = this;
        }

        public bool ModifyReturnBehavior { get; set; }

        private void PreviewKeyDownHandler(object sender, KeyEventArgs e)
        {
            if (!ModifyReturnBehavior)
                return;

            // Modify Return behavior
            if (e.Key == Key.Return && Keyboard.Modifiers == ModifierKeys.None)
            {
                DataGrid.ExecuteCommand(DataPresenterCommands.CellNextByTab);
                e.Handled = true;
            }
        }

        private void DataGridFieldLayoutInitialized(object sender, FieldLayoutInitializedEventArgs e)
        {
            var kindField = this.Resources["KindField"] as Field;
            e.FieldLayout.Fields[1] = kindField;
        }

        public Items Items
        {
            get { return new Items(); }
        }

        public IEnumerable<string> Kinds
        {
            get
            {
                return new[]
                {
                    "Kind1",
                    "Kind2",
                    "Kind3"
                };
            }
        }

        private void ComboEditorEditModeStartedHandler(object sender, EditModeStartedEventArgs e)
        {
            var comboEditor = sender as XamComboEditor;
            if (!comboEditor.IsDropDownOpen)
                comboEditor.IsDropDownOpen = true;
        }
    }

    public class Item
    {
        public int Number { get; set; }
        public string Kind { get; set; }
        public string Note1 { get; set; }
        public string Note2 { get; set; }
    }

    public class Items : ObservableCollection<Item>
    {
        public Items()
        {
            this.Add(new Item() { Number = 0});
            this.Add(new Item() { Number = 1});
            this.Add(new Item() { Number = 2});
        }
    }

}
